@@ -6,7 +6,7 @@
 //! ## Usage Example
 //! ```
 //! use hydrus_api::Client;
-//! use hydrus_api::paths::adding_tags::{AddTagsRequestBuilder, TagAction};
+//! use hydrus_api::endpoints::adding_tags::{AddTagsRequestBuilder, TagAction};
 //! use std::env;
 //! # #[tokio::test]
 //! # async fn doctest() {
@@ -32,11 +32,11 @@
 //! ```
 
 #[macro_use]
-extern crate serde_derive;
+extern crate serde;
 
 pub mod client;
-mod error;
-pub mod paths;
+pub mod endpoints;
+pub mod error;
 pub(crate) mod utils;
 
 pub use client::Client;
